__version__ = "0.8.0"
__author__ = "PyTorchLightning et al."
__author_email__ = "name@pytorchlightning.ai"
__license__ = "Apache-2.0"
__copyright__ = f"Copyright (c) 2020-2022, {__author__}."
__homepage__ = "https://github.com/Lightning-AI/lightning-flash"
__docs_url__ = "https://lightning-flash.readthedocs.io/en/stable/"
__docs__ = "Your PyTorch AI Factory - Flash enables you to easily configure and run complex AI recipes."
__long_doc__ = """
Flash makes complex AI recipes for over 15 tasks across 7 data domains accessible to all.
In a nutshell, Flash is the production grade research framework you always dreamed of but didn't have time to build.
"""

__all__ = [
    "__author__",
    "__author_email__",
    "__copyright__",
    "__docs__",
    "__homepage__",
    "__license__",
    "__version__",
]
